<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

namespace local_ulibot;

/**
 * Ulibot class.
 *
 * @package   local_ulibot
 * @copyright 2023 onwards Daniel Belizán <daniel@e-abclearning.com>
 * @license   http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */
class ulibot {
    /**
     * URL Default constant
     * By default this value is thue
     * ulibot url service.
     * @package    local_ulibot
     * @copyright  2023 e-ABC Learning <daniel@e-abclearning.com>
     * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
     */
    const URLDEFAULT = "https://ulibot.e-abclearning.com";

    /**
     * get_token
     * Return token config to connect
     * to ulibot
     * @return string
     */
    public static function get_token() {
        $token = get_config('local_ulibot', 'tokenulibot');
        return $token;
    }

    /**
     * get_url
     * Return url config to connect
     * to ulibot. URLDEFUALT returned
     * incase empty value
     * @return string
     */
    public static function get_url() {
        $url = get_config('local_ulibot', 'urlulibot');
        if (empty($url)) {
            $url = self::URLDEFAULT;
        }
        return $url;
    }

    /**
     * get_label
     * Return script html label to show
     * widget ulibot on moodle.
     * @return string
     */
    public static function get_label() {
        global $USER, $COURSE, $CFG, $PAGE;
        $config = get_config("local_ulibot");
        $url = self::get_url();
        $token = self::get_token();

        $insertdata = [
            'url' => $url,
            'token' => $token,
            'platform' => 'moodle',
            'version' => $CFG->release,
        ];

        if (!empty($config->urlbackulibot)) {
            $insertdata['backurl'] = $config->urlbackulibot;
        }

        if (!empty($USER->id)) {
            $insertdata['userid'] = $USER->id;
            $insertdata['name'] = fullname($USER);
        }

        if ($COURSE->id > SITEID) {
            $insertdata['courseid'] = $COURSE->id;
            $insertdata['coursename'] = $COURSE->fullname;
            $insertdata['shortname'] = $COURSE->shortname;

            if (!empty($PAGE->cm)) {
                $insertdata['moduleid'] = $PAGE->cm->id;
                $insertdata['modulename'] = $PAGE->cm->name;
                $insertdata['moduletype'] = $PAGE->cm->modname;
                $insertdata['moduleinstanceid'] = $PAGE->cm->instance;
            }
        }

        if (!empty($token)) {
            $jsondata = json_encode($insertdata);
            $label = sprintf("<script async src='%s/widget.js'
                            onload='insertUliBotWidget(%s)'>
                            </script>", $url, $jsondata);
            return $label;
        }
        return '';
    }
}
